@@ -23,7 +23,11 @@ Stone::Stone(const QString &stone, float value)
 {
     if (stone.size() >= 2) {
         m_x = stone[0].toUpper().toLatin1();
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         m_y = stone.midRef(1).toInt();
+#else
+        m_y = stone.mid(1).toInt();
+#endif
     }
 }
 
